@@ -307,10 +307,6 @@ dbus_bool_t _dbus_windows_user_is_process_owner (const char        *windows_sid)
 dbus_bool_t _dbus_append_keyring_directory_for_credentials (DBusString      *directory,
                                                             DBusCredentials *credentials);
 
-dbus_bool_t _dbus_daemon_is_session_bus_address_published (const char *scope);
-
-dbus_bool_t _dbus_daemon_publish_session_bus_address (const char* address, const char* shm_name);
-
 void _dbus_daemon_unpublish_session_bus_address (void);
 
 dbus_bool_t _dbus_socket_can_pass_unix_fd(DBusSocket fd);
